@@ -10,7 +10,7 @@ use Moose::Util::TypeConstraints;
 use List::MoreUtils qw(uniq);
 use POSIX;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 
 subtype 'PositiveInt',
@@ -205,7 +205,11 @@ sub store
 
     # store n-grams
     my $i = 0;
-    for my $k (sort { $self->{_dict}->{$ngram}{$b} <=> $self->{_dict}->{$ngram}{$a} } keys %{$self->{_dict}->{$ngram}}) {
+    for my $k (sort {
+                        $self->{_dict}->{$ngram}{$b} <=> $self->{_dict}->{$ngram}{$a}
+                        ||
+                        $a cmp $b
+                    } keys %{$self->{_dict}->{$ngram}}) {
         print $fhModel "$k\t$self->{_dict}->{$ngram}{$k}\n";
         if ( ++$i > $count ) {
             last;
@@ -222,15 +226,18 @@ sub store
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Lingua::YALI::Builder - Constructs language models for language identification.
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -374,4 +381,3 @@ This is free software, licensed under:
   The (three-clause) BSD License
 
 =cut
-
